@@ -10,7 +10,7 @@ from radar.models.route import Routes
 from radar.errors import RadarError
 from radar.utils import remove_none_values
 
-API_PATH = {
+GEOFENCE_PATH = {
     "geofences": "v1/geofences",
     "geofence_id": "v1/geofences/{id}",
     "geofence_tag": "v1/geofences/{tag}/{externalId}",
@@ -22,16 +22,50 @@ API_PATH = {
     "event_id": "v1/events/{id}",
     "event_verification": "v1/events/{id}/verification",
     "context": "v1/context",
+}
+
+USER_PATH = {
+    "users": "v1/users",
+    "user_id": "v1/users/{id}",
+}
+
+EVENT_PATH = {
+    "events": "v1/events",
+    "event_id": "v1/events/{id}",
+    "event_verification": "v1/events/{id}/verification",
+}
+
+CONTEXT_PATH = {
+    "context": "v1/context",
+}
+
+GEOCODE_PATH = {
     "geocode_forward": "v1/geocode/forward",
     "geocode_reverse": "v1/geocode/reverse",
     "geocode_ip": "v1/geocode/ip",
+}
+
+SEARCH_PATH = {
     "search_users": "v1/search/users",
     "search_geofences": "v1/search/geofences",
     "search_places": "v1/search/places",
     "search_autocomplete": "v1/search/autocomplete",
+}
+
+ROUTE_PATH = {
     "route_distance": "v1/route/distance",
 }
 
+API_PATH = {
+    **GEOFENCE_PATH,
+    **USER_PATH,
+    **EVENT_PATH,
+    **CONTEXT_PATH,
+    **GEOCODE_PATH,
+    **SEARCH_PATH,
+    **ROUTE_PATH,
+}
+
 
 class _Endpoint:
     """Base class defining a Radar API Endpoint
@@ -303,8 +337,11 @@ class Events(_Endpoint):
             >>> radar.events.verify('123', 'accept')
             >>> radar.events.verify('123', value=1)
         """
-        if value and value in [-1, 0, 1]:
-            verify_value = value
+        if value:
+            if value not in [-1, 0, 1]:
+                raise RadarError(
+                    message=f"value must be one of 1 (accept), -1 (reject), 0 (unverify)"
+                )
         else:
             verification_options = {"accept": 1, "reject": -1, "unverify": 0}
             if verification not in verification_options:
@@ -583,10 +620,17 @@ class Route(_Endpoint):
         path = API_PATH["route_distance"]
         (origin_lat, origin_lng) = origin
         (destination_lat, destination_lng) = destination
-        # check modes
-        # check units
-        if units not in ["metric", "imperial"]:
-            raise RadarError("units must be 'metric' or 'imperial'")
+
+        UNIT_OPTIONS = ["metric", "imperial"]
+        if units not in UNIT_OPTIONS:
+            raise RadarError(message="units must be 'metric' or 'imperial'")
+
+        MODE_OPTIONS = ["car", "bike", "transit", "foot"]
+        if not all([mode in MODE_OPTIONS for mode in modes.split(",")]):
+            raise RadarError(
+                message=f"modes must be comma-separated string including one or more of 'foot,bike,car,transit'"
+            )
+
         query_params = {
             "origin": f"{origin_lat},{origin_lng}",
             "destination": f"{destination_lat},{destination_lng}",
