@@ -15,4 +15,6 @@ class Regions(Model):
     _DISPLAY_ATTRIBUTES = (
         "country",
         "state",
+        "dma",
+        "postalCode",
     )
